-- -------------------------------------------------------------------------
-- mysql-db scripts for create tables
-- @autor marc at bouquet dot ch
-- Copyright (c) 2007 Marc Bouquet, 3032 Hinterkappelen. All rights reseved.
-- -------------------------------------------------------------------------

create database if not exists bookstore;
use bookstore;

-- -------------------------------------------------------------------------
-- drop tables
-- -------------------------------------------------------------------------
drop table if exists orders;
drop table if exists line_item;
drop table if exists book;
drop table if exists address;
drop table if exists credit_card;

-- -------------------------------------------------------------------------
-- create table book
-- -------------------------------------------------------------------------
create table book (
  book_id          			int unsigned 	not null auto_increment,
  isbn        				varchar(20) 	null,
  title         			varchar(1024) 	not null,
  authors					varchar(1024) 	not null,
  publisher					varchar(1024) 	not null,
  date						timestamp 		not null,
  binding					varchar(40) 	not null,
  pages						int unsigned 	not null,
  price						double          not null,
  
  primary key  (book_id)
) engine=InnoDB default charset=latin1;

-- -------------------------------------------------------------------------
-- create table address
-- -------------------------------------------------------------------------
create table address (
  address_id          			int unsigned 	not null auto_increment,
  name 							varchar(1024) 	not null,
--email_address					varchar(200) 	null,
  street						varchar(400) 	not null,
  zip							varchar(40) 	not null,
  city							varchar(120) 	not null,
  country						varchar(8) 		not null,
--phone							varchar(120) 	null,
  
  primary key  (address_id)
) engine=InnoDB default charset=latin1;

-- -------------------------------------------------------------------------
-- create table credit_card
-- -------------------------------------------------------------------------
create table credit_card (
  credit_card_id          		int unsigned 	not null auto_increment,
  type							varchar(400) 	not null,
  number						varchar(20) 	not null,
  expiration					timestamp 		not null,
  
  primary key  (credit_card_id)
) engine=InnoDB default charset=latin1;

-- -------------------------------------------------------------------------
-- create table line_item
-- -------------------------------------------------------------------------
create table line_item (
  item_id          			int unsigned 	not null auto_increment,
  book_id        			int unsigned 	not null,
  quantity         			int unsigned 	not null,
  
  primary key  (item_id),
  FOREIGN KEY (book_id) REFERENCES book(book_id)
) engine=InnoDB default charset=latin1;

-- -------------------------------------------------------------------------
-- create table orders
-- -------------------------------------------------------------------------
create table orders (
  order_id          		int unsigned 	not null auto_increment,
  item_id          			int unsigned 	not null,
  address_id          		int unsigned 	not null,
  credit_card_id          	int unsigned 	not null,
  number                    int unsigned    not null,
  date						timestamp 		not null,
  amount        			double 			not null,
  status         			varchar(20) 	not null,
  
  primary key  (order_id),
  FOREIGN KEY (item_id) REFERENCES line_item(item_id) ON DELETE CASCADE,
  FOREIGN KEY (address_id) REFERENCES address(address_id) ON DELETE CASCADE,
  FOREIGN KEY (credit_card_id) REFERENCES credit_card(credit_card_id) ON DELETE CASCADE
) engine=InnoDB default charset=latin1;