package org.books.common;

import java.io.Serializable;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import javax.faces.context.FacesContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.log4j.Logger;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Beschreibung:<br/>
 * Diese Klasse ist eine Utillity-Klasse und kapselt generelle Methoden fuer
 * die Java Beans in der Web-Applikation.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author   Marc Bouquet ( bouquet dot ch, Switzerland )
 * @version  1.0 - 01.05.2007
 */
public class BaseBean implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( BaseBean.class );

  /**
   * Standard Konstruktor
   */
  public BaseBean()
  {
    // Don't do anything
  }

  /**
   * This method created a reference on the FacesContext.
   * @see FacesContext {@link javax.faces.context.FacesContext}
   * @return FacesContext
   */
  protected FacesContext getFacesContext()
  {
    return FacesContext.getCurrentInstance();
  }

  /**
   * This method created a reference on the HttpSession.
   * @see HttpSession {@link javax.servlet.http.HttpSession}
   * @return HttpSession
   */
  protected HttpSession getSession()
  {
    return (HttpSession) getFacesContext().getExternalContext().getSession( true );
  }

  /**
   * This method created a reference on the HttpServletRequest.
   * @see HttpServletRequest {@link javax.servlet.http.HttpServletRequest}
   * @return HttpServletRequest
   */
  protected HttpServletRequest getRequest()
  {
    return (HttpServletRequest) getFacesContext().getExternalContext().getRequest();
  }

  /**
   * This method created a reference on the HttpServletResponse.
   * @see HttpServletResponse {@link javax.servlet.http.HttpServletRequest}
   * @return HttpServletResponse
   */
  protected HttpServletResponse getResponse()
  {
    return (HttpServletResponse) getFacesContext().getExternalContext().getResponse();
  }

  /**
   * This method created a reference on the managed bean.
   * @param managedBeanName String
   * @return Object
   */
  public Object getManagedBean( String managedBeanName )
  {
    return getFacesContext().getELContext().getELResolver().getValue( getFacesContext().getELContext(), null, managedBeanName );
  }

  /**
   * This method returns the i18n key of current locale
   * @param id String i18n key
   * @param bundleName String name of the resourceBundle in the faces-config.xml
   * @return String
   */
  public String getText( String id, String bundleName )
  {
    String text = "???" + id + "???";
    try
    {
      ResourceBundle bundle = getFacesContext().getApplication().getResourceBundle( getFacesContext(), bundleName );
      text = bundle.getString( id );
    }
    catch ( MissingResourceException mrex )
    {
      LOG.error( "MissingResourceException: <" + text + ">" );
    }
    return text;
  }
}
