package org.books.data;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * The class Book contains the data of a book.
 * @author  Stephan Fischli
 * @version  1.0
 */
@Entity
@Table( name = "BOOK" )
public class Book implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * book id (primary key)
   */
  @Id
  @GeneratedValue
  @Column( name = "BOOK_ID" )
  private long bookId;

  @Column( name = "ISBN", unique = true )
  private String isbn;

  @Column( name = "TITLE" )
  private String title;

  @Column( name = "AUTHORS" )
  private String authors;

  @Column( name = "PUBLISHER" )
  private String publisher;

  @Column( name = "DATE" )
  private Date date;

  @Column( name = "BINDING" )
  private String binding;

  @Column( name = "PAGES" )
  private Integer pages;

  @Column( name = "PRICE" )
  private Double price;

  //-----------------------------------------------------------------------------
  // t o S t r i n g ( ) - M E T H O D
  //-----------------------------------------------------------------------------

  /**
   * Return all attributes as String
   * @return Object as String
   */
  @Override
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( " --- toString() of org.books.data.Book -----------------------------------\n" );
    buf.append( "  book id   <" );
    buf.append( getBookId() );
    buf.append( ">\n" );
    buf.append( "  isbn      <" );
    buf.append( getIsbn() );
    buf.append( ">\n" );
    buf.append( "  title     <" );
    buf.append( getTitle() );
    buf.append( ">\n" );
    buf.append( "  authors   <" );
    buf.append( getAuthors() );
    buf.append( ">\n" );
    buf.append( "  publisher <" );
    buf.append( getPublisher() );
    buf.append( ">\n" );
    buf.append( "  date      <" );
    buf.append( getDate() );
    buf.append( ">\n" );
    buf.append( "  binding   <" );
    buf.append( getBinding() );
    buf.append( ">\n" );
    buf.append( "  pages     <" );
    buf.append( getPages() );
    buf.append( ">\n" );
    buf.append( "  price     <" );
    buf.append( getPrice() );
    buf.append( ">\n -------------------------------------------------------------------------" );
    return buf.toString();
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - / S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gets the book id.
   * @return  the book id
   */
  public long getBookId()
  {
    return this.bookId;
  }

  /**
   * Sets the book id.
   * @param bookId  The book id to set
   */
  public void setBookId( long bookId )
  {
    this.bookId = bookId;
  }

  /**
   * Gets the authors.
   * @return  the authors
   */
  public String getAuthors()
  {
    return this.authors;
  }

  /**
   * Sets the authors.
   * @param authors  The authors to set
   */
  public void setAuthors( String authors )
  {
    this.authors = authors;
  }

  /**
   * Gets the binding.
   * @return  the binding
   */
  public String getBinding()
  {
    return this.binding;
  }

  /**
   * Sets the binding.
   * @param binding  The binding to set
   */
  public void setBinding( String binding )
  {
    this.binding = binding;
  }

  /**
   * Gets the date.
   * @return  the date
   */
  public Date getDate()
  {
    return this.date;
  }

  /**
   * Sets the date.
   * @param date  The date to set
   */
  public void setDate( Date date )
  {
    this.date = date;
  }

  /**
   * Gets the isbn.
   * @return  the isbn
   */
  public String getIsbn()
  {
    return this.isbn;
  }

  /**
   * Sets the isbn.
   * @param isbn  The isbn to set
   */
  public void setIsbn( String isbn )
  {
    this.isbn = isbn;
  }

  /**
   * Gets the pages.
   * @return  the pages
   */
  public Integer getPages()
  {
    return this.pages;
  }

  /**
   * Sets the pages.
   * @param pages  The pages to set
   */
  public void setPages( Integer pages )
  {
    this.pages = pages;
  }

  /**
   * Gets the price.
   * @return  the price
   */
  public Double getPrice()
  {
    return this.price;
  }

  /**
   * Sets the price.
   * @param price  The price to set
   */
  public void setPrice( Double price )
  {
    this.price = price;
  }

  /**
   * Gets the publisher.
   * @return  the publisher
   */
  public String getPublisher()
  {
    return this.publisher;
  }

  /**
   * Sets the publisher.
   * @param publisher  The publisher to set
   */
  public void setPublisher( String publisher )
  {
    this.publisher = publisher;
  }

  /**
   * Gets the title.
   * @return  the title
   */
  public String getTitle()
  {
    return this.title;
  }

  /**
   * Sets the title.
   * @param title  The title to set
   */
  public void setTitle( String title )
  {
    this.title = title;
  }
}