package org.books.data;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;

import org.apache.log4j.Logger;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> 
 * Modul: Business-Tier (EJB 3)<br/>
 * Uebung: 1 (Migration auf JBoss)<br/>
 * Beschreibung:<br/> 
 * Diese Klasse enthaelt die Daten einer Kreditkarte.
 * </p> 
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 24.06.2007
 */
@Entity
@Table( name = "CREDIT_CARD" )
public class CreditCard implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private static Logger LOG = Logger.getLogger( CreditCard.class );

  /**
   * primary key of a creditcard
   */
  @Id
  @GeneratedValue
  @Column( name = "CREDIT_CARD_ID" )
  private long creditcardId;

  /**
   * current value in combombox for card typ
   */
  @Column( name = "TYPE" )
  private String type;

  /**
   * credit card number
   */
  @Column( name = "NUMBER" )
  private String number;

  /**
   * expiry date
   */
  @Column( name = "EXPIRATION" )
  private Date expiration;

  //-----------------------------------------------------------------------------
  // t o S t r i n g ( ) - M E T H O D
  //-----------------------------------------------------------------------------

  /**
   * Return all attributes as String
   * @return Object as String
   */
  @Override
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( " --- toString() of org.books.data.CreditCard -----------------------------\n" );
    buf.append( "  creditcard id <" );
    buf.append( getCreditcardId() );
    buf.append( ">\n" );
    buf.append( "  type          <" );
    buf.append( getType() );
    buf.append( ">\n" );
    buf.append( "  number        <" );
    buf.append( getNumber() );
    buf.append( ">\n" );
    buf.append( "  expiration    <" );
    buf.append( getExpiration() );
    buf.append( ">\n -------------------------------------------------------------------------" );
    return buf.toString();
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * get a cerditcard id
   * @return  long
   */
  public long getCreditcardId()
  {
    return creditcardId;
  }

  /**
   * get a type
   * @return  String
   */
  public String getType()
  {
    return type;
  }

  /**
   * get a number
   * @return  String
   */
  public String getNumber()
  {
    return this.number;
  }

  /**
   * get a expiration
   * @return  Date
   */
  public Date getExpiration()
  {
    return expiration;
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * set creditcard id
   * @param  creditcardId
   */
  public void setCreditcardId( long creditcardId )
  {
    this.creditcardId = creditcardId;
  }

  /**
   * set type
   * @param  type
   */
  public void setType( String type )
  {
    this.type = type;
  }

  /**
   * set number
   * @param  number
   */
  public void setNumber( String number )
  {
    this.number = number;
  }

  /**
   * set expiration
   * @param  expiration
   */
  public void setExpiration( Date expiration )
  {
    this.expiration = expiration;
  }
}
