package org.books.data;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

/**
 * The class LineItem contains the data of a line item.
 * @author   Stephan Fischli
 * @version   1.0
 */
@Entity
@Table( name = "LINE_ITEM" )
public class LineItem implements Serializable
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * item id (primary key)
   */
  @Id
  @GeneratedValue
  @Column( name = "ITEM_ID" )
  private long itemId;

  @ManyToOne
  @JoinColumn( name = "book_id" )
  private Book book;

  @Column( name = "QUANTITY" )
  private Integer quantity;

  //-----------------------------------------------------------------------------
  // t o S t r i n g ( ) - M E T H O D
  //-----------------------------------------------------------------------------

  /**
   * Return all attributes as String
   * @return Object as String
   */
  @Override
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( " --- toString() of org.books.data.LineItem -------------------------------\n" );
    buf.append( "  item id  <" );
    buf.append( getItemId() );
    buf.append( ">\n" );
    buf.append( "  book     <" );
    buf.append( getBook().toString() );
    buf.append( ">\n" );
    buf.append( "  quantity <" );
    buf.append( getQuantity() );
    buf.append( ">\n -------------------------------------------------------------------------" );
    return buf.toString();
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - / S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gets the itemId.
   * @return  the itemId
   */
  public long getItemId()
  {
    return this.itemId;
  }

  /**
   * Sets the itemId.
   * @param itemId  The itemId to set
   */
  public void setItemId( long itemId )
  {
    this.itemId = itemId;
  }

  /**
   * get a book
   * @return  Book
   */
  public Book getBook()
  {
    return book;
  }

  /**
   * set a book
   * @param  book
   */
  public void setBook( Book book )
  {
    this.book = book;
  }

  /**
   * get the quantity
   * @return  Integer
   */
  public Integer getQuantity()
  {
    return quantity;
  }

  /**
   * set the quantity
   * @param  quantity
   */
  public void setQuantity( Integer quantity )
  {
    this.quantity = quantity;
  }
}