package org.books.data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * The class Order contains the data of an order.
 * @author   Stephan Fischli
 * @version   1.0
 */
@Entity
@Table( name = "ORDERS" )
public class Order implements Serializable
{

  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * Enumeration
   */
  public enum Status
  {
    /**
     * status open
     */
    Open,
    /**
     * status closed
     */
    Closed,
    /**
     * status canceled
     */
    Canceled
  }

  @Id
  @GeneratedValue
  @Column( name = "ORDER_ID", unique = true )
  private long orderId;

  @Column( name = "NUMBER", unique = true )
  private Integer number;

  @Column( name = "DATE" )
  private Date date;

  @Column( name = "AMOUNT" )
  private Double amount;

  @Column( name = "STATUS" )
  @Enumerated( EnumType.STRING )
  private Order.Status status;

  @OneToOne( cascade = CascadeType.ALL, fetch = FetchType.EAGER )
  @JoinColumn( name = "ADDRESS_ID" )
  private Address address;

  @OneToOne( cascade = CascadeType.ALL, fetch = FetchType.EAGER )
  @JoinColumn( name = "CREDIT_CARD_ID" )
  private CreditCard creditCard;

  @OneToMany( cascade = CascadeType.ALL, fetch = FetchType.EAGER )
  @JoinColumn( name = "ORDER_ID" )
  private List<LineItem> items;

  //-----------------------------------------------------------------------------
  // t o S t r i n g ( ) - M E T H O D
  //-----------------------------------------------------------------------------
  
  /**
   * Return all attributes as String
   * @return Object as String
   */
  @Override
  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append( " --- toString() of org.books.data.Order ----------------------------------\n" );
    buf.append( "  oder id <" );
    buf.append( getOrderId() );
    buf.append( ">\n" );
    buf.append( "  number  <" );
    buf.append( getNumber() );
    buf.append( ">\n" );
    buf.append( "  date    <" );
    buf.append( getDate() );
    buf.append( ">\n" );
    buf.append( "  amount  <" );
    buf.append( getAmount() );
    buf.append( ">\n" );
    buf.append( "  status  <" );
    buf.append( getStatus() );
    buf.append( ">\n" );
    buf.append( "  address <" );
    buf.append( getAddress().toString() );
    buf.append( ">\n" );
    buf.append( "  items   <" );
    buf.append( getItems().toString() );
    buf.append( ">\n -------------------------------------------------------------------------" );
    return buf.toString();
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - / S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gets the order id.
   * @return  the order id
   */
  public long getOrderId()
  {
    return this.orderId;
  }

  /**
   * Sets the order id.
   * @param orderId  The order id to set
   */
  public void setOrderId( long orderId )
  {
    this.orderId = orderId;
  }

  /**
   * Gets the address.
   * @return  the address
   */
  public Address getAddress()
  {
    return this.address;
  }

  /**
   * Sets the address.
   * @param address  The address to set
   */
  public void setAddress( Address address )
  {
    this.address = address;
  }

  /**
   * Gets the amount.
   * @return  the amount
   */
  public Double getAmount()
  {
    return this.amount;
  }

  /**
   * Sets the amount.
   * @param amount  The amount to set
   */
  public void setAmount( Double amount )
  {
    this.amount = amount;
  }

  /**
   * Gets the creditCard.
   * @return  the creditCard
   */
  public CreditCard getCreditCard()
  {
    return this.creditCard;
  }

  /**
   * Sets the creditCard.
   * @param creditCard  The creditCard to set
   */
  public void setCreditCard( CreditCard creditCard )
  {
    this.creditCard = creditCard;
  }

  /**
   * Gets the date.
   * @return  the date
   */
  public Date getDate()
  {
    return this.date;
  }

  /**
   * Sets the date.
   * @param date  The date to set
   */
  public void setDate( Date date )
  {
    this.date = date;
  }

  /**
   * Gets the items.
   * @return  the items
   */
  public List<LineItem> getItems()
  {
    return this.items;
  }

  /**
   * Sets the items.
   * @param items  The items to set
   */
  public void setItems( List<LineItem> items )
  {
    this.items = items;
  }

  /**
   * Gets the number.
   * @return  the number
   */
  public Integer getNumber()
  {
    return this.number;
  }

  /**
   * Sets the number.
   * @param number  The number to set
   */
  public void setNumber( Integer number )
  {
    this.number = number;
  }

  /**
   * Gets the status.
   * @return  the status
   */
  public Order.Status getStatus()
  {
    return this.status;
  }

  /**
   * Sets the status.
   * @param status  The status to set
   */
  public void setStatus( Order.Status status )
  {
    this.status = status;
  }

}