package org.books.model;

import java.util.ArrayList;
import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import org.apache.log4j.Logger;
import org.books.data.Order;
import org.books.exception.OrderNotCancelableException;
import org.books.exception.OrderNotFoundException;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> 
 * Modul: Business-Tier (EJB 3)<br/>
 * Uebung: 4 (statless SessionBean security)<br/>
 * Beschreibung:<br/> 
 * Diese Klasse (Statefull Session Bean) implementiert die Geschaeftslogik fuer
 * die Verwaltung der Bestellungen.
 * </p> 
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 06.07.2007
 * @see AdminManagerLocal @link{org.books.model.AdminManagerLocal}
 * @see AdminManagerRemote @link{org.books.model.AdminManagerRemote}
 */
@Stateless
//@SecurityDomain( "bookstore" )
public class AdminManagerBean implements AdminManagerLocal, AdminManagerRemote
{
  /**
   * constant for the logging
   */
  @SuppressWarnings( "unused" )
  private transient Logger LOG = Logger.getLogger( AdminManagerBean.class );

  @PersistenceContext( unitName = "bookstore" )
  private EntityManager em;

  /**
   * Diese Methode liest alle Bestellungen aus der Datenbank.
   * @return List<Order>
   */
  //@RolesAllowed( { "Employee" } )
  public List<Order> listOrders()
  {
    List<Order> orderList = new ArrayList<Order>();
    List orders = em.createQuery( "from Order o" ).getResultList();
    for ( Object order: orders )
    {
      orderList.add( (Order) order );
    }
    return orderList;
  }

  /**
   * Diese Methode storniert die jeweilige Bestellung.
   * @param orderNumber Integer
   * @throws OrderNotFoundException
   * @throws OrderNotCancelableException
   */
  //@RolesAllowed( { "Administrator" } )
  public void cancelOrder( Integer orderNumber ) throws OrderNotFoundException, OrderNotCancelableException
  {
    Order order = (Order) em.createQuery( "from Order o where o.number=" + orderNumber ).getSingleResult();
    if ( order != null && order.getStatus() != Order.Status.Canceled )
    {
      order.setStatus( Order.Status.Canceled );
    }
  }
}
