package org.books.model;

import java.util.List;

import javax.ejb.Remote;

import org.books.data.Order;
import org.books.exception.OrderNotCancelableException;
import org.books.exception.OrderNotFoundException;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> 
 * Modul: Business-Tier (EJB 3)<br/>
 * Uebung: 4 (statless SessionBean security)<br/>
 * Beschreibung:<br/> 
 * Diese Klasse implementiert die Schnittstelle fuer den entfernten Zugriff auf 
 * das Stateful Session Bean fuer die Verwaltung der Bestellungen.
 * </p> 
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 06.07.2007
 * @see AdminManagerBean @link{org.books.model.AdminManagerBean}
 */
@Remote
public interface AdminManagerRemote
{
  /**
   * Diese Methode liest alle Bestellungen aus der Datenbank.
   * @return List<Order>
   */
  public List<Order> listOrders();

  /**
   * Diese Methode storniert die jeweilige Bestellung.
   * @param orderNumber Integer
   * @throws OrderNotFoundException
   * @throws OrderNotCancelableException
   */
  public void cancelOrder( Integer orderNumber ) throws OrderNotFoundException, OrderNotCancelableException;
}
