package org.books.model;

import java.util.List;

import javax.ejb.Remote;

import org.books.data.Address;
import org.books.data.CreditCard;
import org.books.data.LineItem;
import org.books.data.Order;
import org.books.exception.CreditCardExpiredException;
import org.books.exception.IncompleteConversionalStateException;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> 
 * Modul: Business-Tier (EJB 3)<br/>
 * Uebung: 2 (statless SessionBean)<br/>
 * Beschreibung:<br/> 
 * Diese Klasse implementiert die Schnittstelle fuer den entfernten Zugriff auf 
 * das Stateful Session Bean fuer die Abwicklung der Bestellungen.
 * </p> 
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 29.06.2007
 * @see OrderManagerBean @link{org.books.model.OrderManagerBean}
 */
@Remote
public interface OrderManagerRemote
{
  /**
   * Diese Methode fügt eine Adresse ein.
   * @param address
   */
  public void setAddress( Address address );

  /**
   * Diese Methode fügt die Kreditkarten-Daten ein.
   * @param creditCard
   * @throws CreditCardExpiredException
   */
  public void setCreditCard( CreditCard creditCard ) throws CreditCardExpiredException;

  /**
   * Diese Methode erzeugt eine Bestellung aufgrund der Liste.
   * @param items List<LineItem>
   * @return Order
   * @throws IncompleteConversionalStateException
   */
  public Order orderBooks( List<LineItem> items ) throws IncompleteConversionalStateException;

  /**
   * Diese Methode beendet ein Bestellvorgang
   */
  public void dispose();
}
