package org.books.util;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import org.apache.log4j.Logger;
import org.books.model.AdminManagerLocal;
import org.books.model.AdminManagerRemote;
import org.books.model.CatalogManagerLocal;
import org.books.model.CatalogManagerRemote;
import org.books.model.OrderManagerLocal;
import org.books.model.OrderManagerRemote;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> 
 * Modul: Business-Tier (EJB 3)<br/>
 * Uebung: 2 (Hilfklasse)<br/>
 * Beschreibung:<br/> 
 * Helper class to hide the lookup to the facade bean for the client. <br />
 * Note: <br />
 * With EJB 3.0 there is no need for a business deleate class anymore, since the
 * remote interface can directly be delivered to the client.
 * </p> 
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 25.06.2007
 */
public class BookstoreLocator
{
  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( BookstoreLocator.class );

  /**
   * This method create a lookup on the CatalogManager
   * @return CatalogManagerLocal
   */
  public static CatalogManagerLocal getCatalogManagerLocal()
  {
    Object remoteObj = null;
    try
    {
      remoteObj = new InitialContext().lookup( "bookstore/CatalogManagerBean/local" );
    }
    catch ( NamingException naex )
    {
      LOG.error( "NamingException is: " + naex.getMessage(), naex );
    }
    return (CatalogManagerLocal) PortableRemoteObject.narrow( remoteObj, CatalogManagerLocal.class );
  }

  /**
   * This method create a lookup on the CatalogManager
   * @return CatalogManagerRemote
   */
  public static CatalogManagerRemote getCatalogManagerRemote()
  {
    Object remoteObj = null;
    try
    {
      remoteObj = new InitialContext().lookup( "bookstore/CatalogManagerBean/remote" );
    }
    catch ( NamingException naex )
    {
      LOG.error( "NamingException is: " + naex.getMessage(), naex );
    }
    return (CatalogManagerRemote) PortableRemoteObject.narrow( remoteObj, CatalogManagerRemote.class );
  }

  /**
   * This method create a lookup on the OrderManagerBean
   * @return OrderManagerLocal
   */
  public static OrderManagerLocal getOrderManagerLocal()
  {
    Object remoteObj = null;
    try
    {
      remoteObj = new InitialContext().lookup( "bookstore/OrderManagerBean/local" );
    }
    catch ( NamingException naex )
    {
      LOG.error( "NamingException is: " + naex.getMessage(), naex );
    }
    return (OrderManagerLocal) PortableRemoteObject.narrow( remoteObj, OrderManagerLocal.class );
  }

  /**
   * This method create a lookup on the OrderManagerBean
   * @return OrderManagerRemote
   */
  public static OrderManagerRemote getOrderManagerRemote()
  {
    Object remoteObj = null;
    try
    {
      remoteObj = new InitialContext().lookup( "bookstore/OrderManagerBean/remote" );
    }
    catch ( NamingException naex )
    {
      LOG.error( "NamingException is: " + naex.getMessage(), naex );
    }
    return (OrderManagerRemote) PortableRemoteObject.narrow( remoteObj, OrderManagerRemote.class );
  }

  /**
   * This method create a lookup on the AdminManagerBean
   * @return AdminManagerLocal
   */
  public static AdminManagerLocal getAdminManagerLocal()
  {
    Object remoteObj = null;
    try
    {
      remoteObj = new InitialContext().lookup( "bookstore/AdminManagerBean/local" );
    }
    catch ( NamingException naex )
    {
      LOG.error( "NamingException is: " + naex.getMessage(), naex );
    }
    return (AdminManagerLocal) PortableRemoteObject.narrow( remoteObj, AdminManagerLocal.class );
  }

  /**
   * This method create a lookup on the AdminManagerBean
   * @return AdminManagerRemote
   */
  public static AdminManagerRemote getAdminManagerRemote()
  {
    Object remoteObj = null;
    try
    {
      remoteObj = new InitialContext().lookup( "bookstore/AdminManagerBean/remote" );
    }
    catch ( NamingException naex )
    {
      LOG.error( "NamingException is: " + naex.getMessage(), naex );
    }
    return (AdminManagerRemote) PortableRemoteObject.narrow( remoteObj, AdminManagerRemote.class );
  }
}