package org.books.view;

import java.util.ArrayList;
import java.util.List;

import javax.faces.model.SelectItem;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.Address;

/**
 * The class Address contains the data of an address.
 * @author  Stephan Fischli and marc at bouquet dot ch
 * @version  1.1
 * @see BaseBean  @link{org.books.common.BaseBean}
 */
public class AddressBean extends BaseBean
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( AddressBean.class );

  /**
   * view id
   */
  private String viewId;

  /**
   * Data object of a address 
   */
  private Address address = new Address();

  /**
   * combombox for country
   */
  private List<SelectItem> countryList;

  /**
   * Default constrcutor
   */
  public AddressBean()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call Address()-constructor ..." );
    }
  }

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S   F O R   N A V I G A T I O N   H A N D L I N G
  //-----------------------------------------------------------------------------

  /**
   * This method call the address view.
   * @return String value for the navigation handling
   */
  public String address()
  {
    this.viewId = getFacesContext().getViewRoot().getViewId();
    loadCountryList();
    return CommonConstants.NAVIGATION_ADDRESS;
  }

  /**
   * This method call the credit card view.
   * @return String value for the navigation handling
   */
  public String credit()
  {
    if ( this.viewId.equals( "/order.jsp" ) )
    {
      return CommonConstants.NAVIGATION_ORDER;
    }
    else
    {
      return CommonConstants.NAVIGATION_CREDIT;
    }
  }

  /**
   * This method reset all values
   * @return String value for the navigation handling
   */
  public String reset()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call reset()-method ..." );
    }
    loadCountryList();
    setName( CommonConstants.SEPARATOR_NULL_VALUE );
    setStreet( CommonConstants.SEPARATOR_NULL_VALUE );
    setCity( CommonConstants.SEPARATOR_NULL_VALUE );
    setZip( CommonConstants.SEPARATOR_NULL_VALUE );
    return CommonConstants.NAVIGATION_SUCCESS;
  }

  /**
   * load a list with countries
   */
  public void loadCountryList()
  {
    List<SelectItem> list = new ArrayList<SelectItem>();
    list.add( new SelectItem( "CH", getText( "country_ch", CommonConstants.RES_TXT ) ) );
    list.add( new SelectItem( "DE", getText( "country_de", CommonConstants.RES_TXT ) ) );
    list.add( new SelectItem( "FR", getText( "country_fr", CommonConstants.RES_TXT ) ) );
    list.add( new SelectItem( "IT", getText( "country_it", CommonConstants.RES_TXT ) ) );
    list.add( new SelectItem( "AT", getText( "country_at", CommonConstants.RES_TXT ) ) );
    setCountry( "CH" );
    setCountryList( list );
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * return the address data object
   * @return Address
   */
  public Address getAddress()
  {
    return this.address;
  }

  /**
   * Gets the countryList.
   * @return  the countryList
   */
  public List<SelectItem> getCountryList()
  {
    return this.countryList;
  }

  /**
   * get a name
   * @return  String
   */
  public String getName()
  {
    return this.address.getName();
  }

  /**
   * get a street
   * @return  String
   */
  public String getStreet()
  {
    return this.address.getStreet();
  }

  /**
   * get a city
   * @return  String
   */
  public String getCity()
  {
    return this.address.getCity();
  }

  /**
   * get a zip
   * @return  String
   */
  public String getZip()
  {
    return this.address.getZip();
  }

  /**
   * get current country
   * @return  String
   */
  public String getCountry()
  {
    return this.address.getCountry();
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Sets the countryList.
   * @param countryList  The countryList to set
   */
  public void setCountryList( List<SelectItem> countryList )
  {
    this.countryList = countryList;
  }

  /**
   * set name
   * @param  name
   */
  public void setName( String name )
  {
    this.address.setName( name );
  }

  /**
   * set street
   * @param  street
   */
  public void setStreet( String street )
  {
    this.address.setStreet( street );
  }

  /**
   * set city
   * @param  city
   */
  public void setCity( String city )
  {
    this.address.setCity( city );
  }

  /**
   * set zip
   * @param  zip
   */
  public void setZip( String zip )
  {
    this.address.setZip( zip );
  }

  /**
   * set current country
   * @param  country
   */
  public void setCountry( String country )
  {
    this.address.setCountry( country );
  }
}