package org.books.view;

import java.util.Iterator;
import java.util.List;

import javax.faces.model.DataModel;
import javax.faces.model.ListDataModel;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.LineItem;
import org.books.data.Order;
import org.books.exception.OrderNotCancelableException;
import org.books.exception.OrderNotFoundException;
import org.books.model.AdminManagerLocal;
import org.books.util.BookstoreLocator;

/**
 * <p> CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> Modul: Web-Tier (JSF)<br/> Uebung: Pruefungsaufgabe<br/> Beschreibung:<br/> Diese Klasse kapselt als Backing Bean die Aufrufe fuer den Admin-Bereich. </p> <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author      Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version     1.0 - 10.05.2007
 * @see BaseBean   @link{org.books.common.BaseBean}
 */
public class AdminBean extends BaseBean
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( AdminBean.class );

  private List<Order> orderList;

  private DataModel adminModel = new ListDataModel();

  private Order order;

  /** The admin manager. */
  private AdminManagerLocal adminManager = BookstoreLocator.getAdminManagerLocal();

  /**
   * Default constrcutor
   */
  public AdminBean()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call AdminBean()-constructor ..." );
    }
    refresh();
  }

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S   F O R   N A V I G A T I O N   H A N D L I N G
  //-----------------------------------------------------------------------------

  /**
   * This method select the current row data.
   * @return String value for the navigation handling
   */
  public String select()
  {
    setOrder( (Order) getAdminModel().getRowData() );
    return CommonConstants.NAVIGATION_SUCCESS;
  }

  /**
   * This method cancel the selected row data.
   * @return String value for the navigation handling
   */
  public String cancel()
  {
    try
    {
      Order order = (Order) getAdminModel().getRowData();
      order.setStatus( Order.Status.Canceled );
      adminManager.cancelOrder( order.getNumber() );
    }
    catch ( OrderNotFoundException onfex )
    {
      LOG.error( "OrderNotFoundException: " + onfex.getMessage(), onfex );
      MessageFactory.error( "error_admin_order_not_found" );
    }
    catch ( OrderNotCancelableException oncex )
    {
      MessageFactory.error( "error_admin_order_cancel" );
    }
    return CommonConstants.NAVIGATION_SUCCESS;
  }

  /**
   * This method refresh the data table for overview.
   * @return String value for the navigation handling
   */
  public String refresh()
  {
    setOrderList( adminManager.listOrders() );
    getAdminModel().setWrappedData( getOrderList() );
    return CommonConstants.NAVIGATION_SUCCESS;
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gibt das Datenmodel zurueck.
   * @return  DataModel
   */
  public DataModel getAdminModel()
  {
    return this.adminModel;
  }

  /**
   * get order object
   * @return  Order
   */
  public Order getOrder()
  {
    return this.order;
  }

  /**
   * get order list
   * @return  List
   */
  public List<Order> getOrderList()
  {
    return this.orderList;
  }

  /**
   * Gibt den Gesamtpreis der Bestellung zurueck.
   * @return double
   */
  public double getTotalOrder()
  {
    double total = 0;
    if ( getOrder().getItems() != null && getOrder().getItems().size() > 0 )
    {
      Iterator iter = getOrder().getItems().iterator();
      while ( iter.hasNext() )
      {
        LineItem item = (LineItem) iter.next();
        total = total + ( item.getQuantity() * item.getBook().getPrice() );
      }
    }
    return total;
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * set order
   * @param order  Order
   */
  public void setOrder( Order order )
  {
    this.order = order;
  }

  /**
   * set order list
   * @param  list
   */
  public void setOrderList( List<Order> list )
  {
    this.orderList = list;
  }
}