package org.books.view;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.faces.model.DataModel;
import javax.faces.model.ListDataModel;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.Book;
import org.books.data.LineItem;

/**
 * <p> CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> Modul: Web-Tier (JSF)<br/> Uebung: 8 (Shopping Card)<br/> Beschreibung:<br/> Diese Klasse kapselt als Backing Bean die Aufrufe fuer den Warenkrob. </p> <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 01.05.2007
 * @see BaseBean  @link{org.books.common.BaseBean}
 */
public class CardBean extends BaseBean
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( CardBean.class );

  /**
   * Validierungsfehler Flag
   */
  private boolean isFailures = false;

  /**
   * List mit LineItem Objekten
   */
  private List<LineItem> cardList;

  /**
   * Datenmodell fuer Warenkorb
   */
  private DataModel cardModel = new ListDataModel();

  /**
   * Default constrcutor
   */
  public CardBean()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call CardBean()-constructor ..." );
    }
  }

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S   F O R   N A V I G A T I O N   H A N D L I N G
  //-----------------------------------------------------------------------------

  /**
   * Diese Methode fuegt eine Bestellung zum Warenkrob hinzu.
   * @return String value for the navigation handling
   */
  public String add()
  {
    if ( getCardList() == null )
    {
      setCardList( new ArrayList<LineItem>() );
    }
    Book book = (Book) getCatalogBean().getBookModel().getRowData();
    int position = checkCards( book.getTitle() );
    if ( position != -1 )
    {
      LineItem item = (LineItem) getCardList().get( position );
      item.setQuantity( item.getQuantity() + 1 );
    }
    else
    {
      LineItem item = new LineItem();
      item.setQuantity( 1 );
      item.setBook( book );
      getCardList().add( item );
    }
    getCardModel().setWrappedData( getCardList() );
    return CommonConstants.NAVIGATION_CARD_ADD;
  }

  /**
   * Diese Methode entfernt eine Bestellung aus dem Warenkrob.
   * @return String value for the navigation handling
   */
  public String remove()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "getCardModel().getRowIndex() is:<" + getCardModel().getRowIndex() + ">" );
    }
    getCardList().remove( getCardModel().getRowIndex() );
    getCardModel().setWrappedData( getCardList() );
    return CommonConstants.NAVIGATION_CARD_REMOVE;
  }

  /**
   * Diese Methode aktualisiert den Warenkorb.
   * @return String value for the navigation handling
   */
  public String refresh()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call refresh()-method ..." );
    }

    if ( getCardList() != null && getCardList().size() > 0 )
    {
      setFailures( false );
      int count = 0;
      Iterator iter = getCardList().iterator();
      while ( iter.hasNext() )
      {
        LineItem item = (LineItem) iter.next();
        if ( item.getQuantity() == 0 || item.getQuantity() < 0 )
        {
          String componentId = "id_card:cards:" + count + ":txf_quantity";
          MessageFactory.error( componentId, CommonConstants.ERR_NUMBER_NO_POSITIV );
          LOG.error( "number must positiv" );
          setFailures( true );
          break;
        }
        count++;
      }
    }
    return CommonConstants.NAVIGATION_CARD_REFRESH;
  }

  /**
   * Diese Methode löscht den Warenkorb.
   * @return String value for the navigation handling
   */
  public String clear()
  {
    setCardList( null );
    cardModel = new ListDataModel();
    return CommonConstants.NAVIGATION_CARD_CLEAR;
  }

  /**
   * Diese Methode ueberprueft, ob bereits ein Buch mit dem Titel enthalten ist.
   * Wenn ja, wird nur die Anzahl der Artikel um eines erhöht.
   * @param title String
   * @return int position
   */
  private int checkCards( String title )
  {
    int position = -1;
    int count = 0;
    if ( getCardList() != null && getCardList().size() > 0 )
    {
      Iterator iter = getCardList().iterator();
      while ( iter.hasNext() )
      {
        LineItem item = (LineItem) iter.next();
        if ( item.getBook().getTitle().equals( title ) )
        {
          position = count;
        }
        count++;
      }
    }
    return position;
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Gibt den Gesamtpreis des Warenkorbs zurueck.
   * @return double
   */
  public double getTotal()
  {
    double total = 0;
    if ( getCardList() != null && getCardList().size() > 0 )
    {
      Iterator iter = getCardList().iterator();
      while ( iter.hasNext() )
      {
        LineItem item = (LineItem) iter.next();
        double sum;
        if ( item.getQuantity() < 0 )
        {
          sum = 0 * item.getBook().getPrice();
        }
        else
        {
          sum = item.getQuantity() * item.getBook().getPrice();
        }
        total = total + sum;
      }
    }
    return total;
  }

  /**
   * Gibt eine Liste des Warenkorbes mit LineItem Value-Objekten zurueck.
   * @return  List
   */
  public List<LineItem> getCardList()
  {
    return this.cardList;
  }

  /**
   * Gibt das Datenmodel zurueck.
   * @return  DataModel
   */
  public DataModel getCardModel()
  {
    return this.cardModel;
  }

  /**
   * Referenz auf das Catalog Bean
   * @return CatalogBean
   */
  public CatalogBean getCatalogBean()
  {
    return (CatalogBean) getManagedBean( CommonConstants.MBEAN_CATALOG_BEAN );
  }

  /**
   * Flag fuer Validierungsfehler
   * @return  boolean true=hat Fehler (Button disabled), false= hat keine Fehler (Button aktiviert)
   */
  public boolean isFailures()
  {
    return this.isFailures;
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Setzt CardList mit LineItem Value-Objekten.
   * @param list  List
   */
  public void setCardList( List<LineItem> list )
  {
    this.cardList = list;
  }

  /**
   * Setzt das Flag.
   * @param isFailures  boolean
   */
  public void setFailures( boolean isFailures )
  {
    this.isFailures = isFailures;
  }
}
