package org.books.view;

import javax.faces.application.FacesMessage;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.validator.Validator;
import javax.faces.validator.ValidatorException;

import org.apache.log4j.Logger;
import org.books.common.CommonConstants;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Uebung: 9 (Validator)<br/>
 * Beschreibung:<br/>
 * Diese Klasse validiert die Nummer der Kreditkarte und wirft bei Ungueltigkeit,
 * eine Fehlermeldung.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version   1.0 - 04.05.2007
 * @see       Validator @link{javax.faces.validator.Validator}
 */
public class CardNumberValidator implements Validator
{
  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( CardNumberValidator.class );

  /**
   * Validiert das Format einer Kreditkarten Nummer.<br/>
   * Validates the format of a credit card number.
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @param component UIComponent {@link javax.faces.component.UIComponent} the component
   * @param value Object
   * @throws ValidatorException Validierungsfehler
   */
  public void validate( FacesContext context, UIComponent component, Object value ) throws ValidatorException
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call validate()-method ..." );
    }
    if ( !value.toString().trim().matches( "\\d{16}|(\\d{4} \\d{4} \\d{4} \\d{4})|(\\d{4})-(\\d{4})-(\\d{4})-(\\d{4})" ) )
    {
      LOG.error( "credit card has invalid format!" );
      throw new ValidatorException( MessageFactory.getMessage( FacesMessage.SEVERITY_ERROR, CommonConstants.ERR_CREDITCARD_INVALID_FORMAT ) );
    }
  }
}