package org.books.view;

import java.util.List;

import javax.faces.model.DataModel;
import javax.faces.model.ListDataModel;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.Book;
import org.books.model.CatalogManagerLocal;
import org.books.util.BookstoreLocator;

/**
 * <p> CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> Modul: Web-Tier (JSF)<br/> Uebung: 4 (Backing Bean)<br/> Beschreibung:<br/> Diese Klasse kapselt als Backing Bean die Aufrufe fuer den Katalog. </p> <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author      Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version     1.0 - 23.04.2007
 * @see BaseBean   @link{org.books.common.BaseBean}
 */
public class CatalogBean extends BaseBean
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( CatalogBean.class );

  /** The catalog manager. */
  private CatalogManagerLocal catalogManagerLocal = BookstoreLocator.getCatalogManagerLocal();

  /**
   * Titel eines Buches
   */
  private String title;

  /**
   * Autor eines Buches
   */
  private String author;

  /**
   * Verlag eines Buches
   */
  private String publisher;

  /**
   * Liste von gefundenen Buecher
   */
  private List bookList;

  private Book book;

  /**
   * Data model for books
   */
  private DataModel bookModel = new ListDataModel();

  /**
   * Default constructor
   */
  public CatalogBean()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call CatalogBean()-constructor ..." );
    }
  }

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S   F O R   N A V I G A T I O N   H A N D L I N G
  //-----------------------------------------------------------------------------

  /**
   * Diese Methode sucht nach Buechern.
   * @return String value for the navigation handling
   */
  public String searchBooks()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call searchBooks()-method ..." );
    }
    setBookList( catalogManagerLocal.searchBooks( getTitle(), getAuthor(), getPublisher() ) );
    bookModel.setWrappedData( getBookList() );
    LOG.debug( "Size of BookList is: <" + getBookList().size() + ">" );
    if ( getBookList().size() <= 0 )
    {
      MessageFactory.info( CommonConstants.ERR_NO_BOOK_FOUND );
      if ( LOG.isInfoEnabled() )
      {
        LOG.info( "no books found!" );
      }
      return "search_failure";
    }
    return CommonConstants.NAVIGATION_SEARCH_SUCCESS;
  }

  /**
   * Diese Methode selektiert das ausgewaehlte Buch.
   * @return String value for the navigation handling
   */
  public String select()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call select()-method ..." );
    }
    setBook( (Book) getBookModel().getRowData() );
    return CommonConstants.NAVIGATION_DETAIL_SUCCESS;
  }

  /**
   * Diese Methode setzt alle Felder auf die Standardeinstellung zurueck.
   * @return String value for the navigation handling
   */
  public String reset()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call reset()-method ..." );
    }
    setBookList( null );
    setTitle( CommonConstants.SEPARATOR_NULL_VALUE );
    setPublisher( CommonConstants.SEPARATOR_NULL_VALUE );
    setAuthor( CommonConstants.SEPARATOR_NULL_VALUE );
    return CommonConstants.NAVIGATION_SUCCESS;
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * get title
   * @return  String
   */
  public String getTitle()
  {
    return this.title;
  }

  /**
   * get author
   * @return  String
   */
  public String getAuthor()
  {
    return this.author;
  }

  /**
   * get publisher
   * @return  String
   */
  public String getPublisher()
  {
    return this.publisher;
  }

  /**
   * get book list
   * @return  List
   */
  public List getBookList()
  {
    return this.bookList;
  }

  /**
   * get book model
   * @return  bookModel
   */
  public DataModel getBookModel()
  {
    return this.bookModel;
  }

  /**
   * get the selected book
   * @return  book
   */
  public Book getBook()
  {
    return this.book;
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * set title
   * @param value  String
   */
  public void setTitle( String value )
  {
    this.title = value;
  }

  /**
   * set author
   * @param value  String
   */
  public void setAuthor( String value )
  {
    this.author = value;
  }

  /**
   * set publisher
   * @param value  String
   */
  public void setPublisher( String value )
  {
    this.publisher = value;
  }

  /**
   * set book list
   * @param list  List
   */
  public void setBookList( List list )
  {
    this.bookList = list;
  }

  /**
   * set a book
   * @param  book
   */
  public void setBook( Book book )
  {
    this.book = book;
  }
}
