package org.books.view;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.faces.model.SelectItem;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.CreditCard;

/**
 * The class CreditCard contains the data of a credit card.
 * @author  Stephan Fischli and marc at bouquet dot ch
 * @version  1.1
 * @see BaseBean  @link{org.books.common.BaseBean}
 */
public class CreditCardBean extends BaseBean
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( CreditCardBean.class );

  /**
   * Data object of a creditcard
   */
  private CreditCard creditCard = new CreditCard();

  /**
   * combombox for card typ
   */
  private List<SelectItem> cardTypList;

  /**
   * Default constrcutor
   */
  public CreditCardBean()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call CreditCard()-constructor ..." );
    }
    loadCardTypList();
  }

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S   F O R   N A V I G A T I O N   H A N D L I N G
  //-----------------------------------------------------------------------------

  /**
   * This method call the credit card view.
   * @return String value for the navigation handling
   */
  public String credit()
  {
    return CommonConstants.NAVIGATION_CREDIT;
  }

  /**
   * This method call the order view.
   * @return String value for the navigation handling
   */
  public String order()
  {
    return CommonConstants.NAVIGATION_ORDER;
  }

  /**
   * This method reset all values
   * @return String value for the navigation handling
   */
  public String reset()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call reset()-method ..." );
    }
    loadCardTypList();
    setType( CommonConstants.SEPARATOR_NULL_VALUE );
    setNumber( CommonConstants.SEPARATOR_NULL_VALUE );
    setExpiration( null );
    return CommonConstants.NAVIGATION_SUCCESS;
  }

  /**
   * load cardtyp list
   */
  private void loadCardTypList()
  {
    List<SelectItem> list = new ArrayList<SelectItem>();
    list.add( new SelectItem( "1", getText( "creditcard_typ_1", CommonConstants.RES_TXT ) ) );
    list.add( new SelectItem( "2", getText( "creditcard_typ_2", CommonConstants.RES_TXT ) ) );
    list.add( new SelectItem( "3", getText( "creditcard_typ_3", CommonConstants.RES_TXT ) ) );
    setType( "1" );
    setCardTypList( list );
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * return the creditcard data object
   * @return CreditCard
   */
  public CreditCard getCreditCard()
  {
    return this.creditCard;
  }

  /**
   * Gets the currentCardTyp.
   * @return  the currentCardTyp
   */
  public List<SelectItem> getCardTypList()
  {
    return this.cardTypList;
  }

  /**
   * get a type
   * @return  String
   */
  public String getType()
  {
    return this.creditCard.getType();
  }

  /**
   * get a number
   * @return  String
   */
  public String getNumber()
  {
    return this.creditCard.getNumber();
  }

  /**
   * get a expiration
   * @return  Date
   */
  public Date getExpiration()
  {
    return this.creditCard.getExpiration();
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Sets the cardTypList.
   * @param cardTypList  The cardTypList to set
   */
  public void setCardTypList( List<SelectItem> cardTypList )
  {
    this.cardTypList = cardTypList;
  }

  /**
   * set type
   * @param  type
   */
  public void setType( String type )
  {
    this.creditCard.setType( type );
  }

  /**
   * set number
   * @param  number
   */
  public void setNumber( String number )
  {
    this.creditCard.setNumber( number );
  }

  /**
   * set expiration
   * @param  expiration
   */
  public void setExpiration( Date expiration )
  {
    this.creditCard.setExpiration( expiration );
  }
}