package org.books.view;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;

import org.apache.log4j.Logger;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Beschreibung:<br/>
 * Diese Klasse ist eine Utillity-Klasse und verwaltet die Fehlermeldungen und
 * gibt diese als FacesMessage weiter.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author   Marc Bouquet ( bouquet dot ch, Switzerland )
 * @version  1.0 - 01.05.2007
 */
public class MessageFactory
{
  /**
   * constant for the logging
   */
  @SuppressWarnings("unused")
  private static Logger LOG = Logger.getLogger( MessageFactory.class );

  /**
   * Returns a localized message.
   * @param severity FacesMessage.Severity
   * @param id String
   * @param params Object
   * @return FacesMessage
   */
  public static FacesMessage getMessage( FacesMessage.Severity severity, String id, Object... params )
  {
    FacesContext context = FacesContext.getCurrentInstance();
    String name = context.getApplication().getMessageBundle();
    if ( name == null )
    {
      name = FacesMessage.FACES_MESSAGES;
    }
    Locale locale = context.getViewRoot().getLocale();
    ResourceBundle bundle = ResourceBundle.getBundle( name, locale );
    String summary = "???" + id + "???";
    String detail = null;
    try
    {
      summary = MessageFormat.format( bundle.getString( id ), params );
      detail = MessageFormat.format( bundle.getString( id + "_detail" ), params );
    }
    catch ( MissingResourceException e )
    {
    }
    return new FacesMessage( severity, summary, detail );
  }

  /** Returns a localized message.
   * @param id String
   * @param params Object
   * @return FacesMessage
   */
  public static FacesMessage getMessage( String id, Object... params )
  {
    return getMessage( FacesMessage.SEVERITY_INFO, id, params );
  }

  /**
   * Adds an fatal message to the faces context.
   * @param id String
   * @param params Object
   */
  public static void fatal( String id, Object... params )
  {
    fatal( null, id, params );
  }

  /**
   * Adds an fatal message to the faces context.
   * @param componentId String
   * @param id String
   * @param params Object
   */
  public static void fatal( String componentId, String id, Object... params )
  {
    FacesContext context = FacesContext.getCurrentInstance();
    context.addMessage( componentId, getMessage( FacesMessage.SEVERITY_FATAL, id, params ) );
  }

  /**
   * Adds an error message to the faces context.
   * @param id String
   * @param params Object
   */
  public static void error( String id, Object... params )
  {
    error( null, id, params );
  }

  /**
   * Adds an error message to the faces context.
   * @param componentId String
   * @param id String
   * @param params Object
   */
  public static void error( String componentId, String id, Object... params )
  {
    FacesContext context = FacesContext.getCurrentInstance();
    context.addMessage( componentId, getMessage( FacesMessage.SEVERITY_ERROR, id, params ) );
  }

  /**
   * Adds an informational message to the faces context.
   * @param id String
   * @param params Object
   */
  public static void info( String id, Object... params )
  {
    info( null, id, params );
  }

  /**
   * Adds an informational message to the faces context.
   * @param componentId String
   * @param id String
   * @param params Object
   */
  public static void info( String componentId, String id, Object... params )
  {
    FacesContext context = FacesContext.getCurrentInstance();
    context.addMessage( componentId, getMessage( FacesMessage.SEVERITY_INFO, id, params ) );
  }

  /**
   * Adds an warning message to the faces context.
   * @param id String
   * @param params Object
   */
  public static void warn( String id, Object... params )
  {
    warn( null, id, params );
  }

  /**
   * Adds an warn message to the faces context.
   * @param componentId String
   * @param id String
   * @param params Object
   */
  public static void warn( String componentId, String id, Object... params )
  {
    FacesContext context = FacesContext.getCurrentInstance();
    context.addMessage( componentId, getMessage( FacesMessage.SEVERITY_WARN, id, params ) );
  }
}
