package org.books.view;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.Order;
import org.books.exception.CreditCardExpiredException;
import org.books.exception.IncompleteConversionalStateException;
import org.books.model.OrderManagerLocal;
import org.books.util.BookstoreLocator;

/**
 * <p> CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/> Uebung: 9 (Validator) und 11 (Ordering)<br/>
 * Beschreibung:<br/> Diese Klasse kapselt als Backing Bean die Aufrufe fuer die Bestellungen.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author      Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version     1.1 - 08.05.2007
 * @see BaseBean   @link{org.books.common.BaseBean}
 */
public class OrderBean extends BaseBean
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( OrderBean.class );

  /**
   * one order object
   */
  private Order order;

  /** 
   * order manager
   */
  private OrderManagerLocal orderManager;

  /**
   * Default constrcutor
   */
  public OrderBean()
  {
    if ( LOG.isDebugEnabled() )
    {
      LOG.debug( "call OrderBean()-constructor ..." );
    }
  }

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S   F O R   N A V I G A T I O N   H A N D L I N G
  //-----------------------------------------------------------------------------

  /**
   * Diese Methode speichert die Bestellung.
   * @return String value for the navigation handling
   */
  public String send()
  {
    try
    {
      getOrderManager().setAddress( getAddressBean().getAddress() );
      getOrderManager().setCreditCard( getCreditCardBean().getCreditCard() );
      setOrder( getOrderManager().orderBooks( getCardBean().getCardList() ) );

      getCardBean().clear();
      getAddressBean().reset();
      getCreditCardBean().reset();
      getOrderManager().dispose();
      this.orderManager = null;
      return CommonConstants.NAVIGATION_SUCCESS;
    }
    catch ( CreditCardExpiredException ccex )
    {
      MessageFactory.error( CommonConstants.ERR_CREDITCARD_INVALID );
      LOG.error( "CreditCardExpiredException is: <invalid credit card>" );
    }
    catch ( IncompleteConversionalStateException e )
    {
      MessageFactory.error( CommonConstants.ERR_INCOMPLETE_ORDER );
      LOG.error( "IncompleteConversionalStateException is: <incomplete order>" );
    }
    return CommonConstants.NAVIGATION_ORDER;
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * get order object
   * @return  Order
   */
  public Order getOrder()
  {
    return this.order;
  }

  /**
   * reference to the card bean
   * @return CardBean
   */
  public CardBean getCardBean()
  {
    return (CardBean) getManagedBean( CommonConstants.MBEAN_CARD_BEAN );
  }

  /**
   * reference to the address bean
   * @return Address
   */
  public AddressBean getAddressBean()
  {
    return (AddressBean) getManagedBean( CommonConstants.MBEAN_ADDRESS_BEAN );
  }

  /**
   * reference to the credit card bean
   * @return CreditCard
   */
  public CreditCardBean getCreditCardBean()
  {
    return (CreditCardBean) getManagedBean( CommonConstants.MBEAN_CREDITCARD_BEAN );
  }

  /**
   * reference to the order manager
   * @return OrderManager
   */
  private OrderManagerLocal getOrderManager()
  {
    if ( this.orderManager == null )
    {
      this.orderManager = BookstoreLocator.getOrderManagerLocal();
    }
    return this.orderManager;
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * set a order
   * @param  order
   */
  public void setOrder( Order order )
  {
    this.order = order;
  }
}
