package org.books.view;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;

import org.apache.log4j.Logger;
import org.books.common.BaseBean;
import org.books.common.CommonConstants;
import org.books.data.Order;
import org.books.data.Order.Status;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Uebung: 11 (Ordering)<br/>
 * Beschreibung:<br/>
 * Diese Klasse konvertiert den Order.Status fuer die Ausgabe.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version   1.0 - 08.05.2007
 * @see       BaseBean @link{org.books.common.BaseBean}
 * @see       Converter @link{javax.faces.convert.Converter}
 */
public class StatusConverter extends BaseBean implements Converter
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;
  
  /**
   * constant for the logging
   */
  private static Logger LOG = Logger.getLogger( StatusConverter.class );

  /**
   * Convert string value into a object
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @param component UIComponent {@link javax.faces.component.UIComponent} the component
   * @param value String the value to be converted
   */
  public Object getAsObject( FacesContext context, UIComponent component, String value ) throws ConverterException
  {
    return value;
  }

  /**
   * Convert object into a string
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @param component UIComponent {@link javax.faces.component.UIComponent} the component
   * @param obj Object the value to be converted
   */
  public String getAsString( FacesContext context, UIComponent component, Object obj ) throws ConverterException
  {
    if ( obj == null || !( obj instanceof Order.Status ) )
    {
      LOG.error( "unknow order status!" );
      return getText( CommonConstants.CONVERT_CONFORMATION + "_unknown", CommonConstants.RES_TXT  );
    }

    Order.Status status = (Order.Status) obj;
    if ( status.equals( Status.Open ) )
    {
      return getText( CommonConstants.CONVERT_CONFORMATION + "status_1", CommonConstants.RES_TXT  );
    }
    else if ( status.equals( Status.Closed ) )
    {
      return getText( CommonConstants.CONVERT_CONFORMATION + "status_2", CommonConstants.RES_TXT  );
    }
    else if ( status.equals( Status.Canceled ) )
    {
      return getText( CommonConstants.CONVERT_CONFORMATION + "status_3", CommonConstants.RES_TXT  );
    }
    else
    {
      LOG.error( "unknow order status!" );
      return getText( CommonConstants.CONVERT_CONFORMATION + "unknown", CommonConstants.RES_TXT  );
    }
  }
}
