package org.books.view.component;

import java.io.IOException;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Map;

import javax.faces.component.UIInput;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Uebung: 14 (Custom_Components)<br/>
 * Beschreibung:<br/>
 * Diese Klasse implementiert eine Eingabe Komponente fuer das Verfalldatum einer Kreditkarte.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version   1.0 - 14.05.2007
 * @see       UIInput @link{javax.faces.component.UIInput}
 */
public class InputExpiration extends UIInput
{
  /** The identifier of the component. */
  public static final String COMPONENT_TYPE = "InputExpiration";

  /**
   * Default constructor sets the renderer type.
   */
  public InputExpiration()
  {
    setRendererType( null );
  }

  /** Renders the date to the response.
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @throws IOException
   */
  public void encodeBegin( FacesContext context ) throws IOException
  {
    // get current date value
    Calendar calendar = new GregorianCalendar();
    if ( getValue() != null )
    {
      calendar.setTime( (Date) getValue() );
    }
    int year = calendar.get( Calendar.YEAR );
    int month = calendar.get( Calendar.MONTH ) + 1;

    // write year selection
    String clientId = getClientId( context );
    ResponseWriter writer = context.getResponseWriter();
    writer.startElement( "select", this );
    writer.writeAttribute( "name", clientId + ":year", null );
    for ( int value = year; value < year + 10; value++ )
    {
      writer.startElement( "option", this );
      writer.writeAttribute( "value", value, null );
      if ( value == year )
      {
        writer.writeAttribute( "selected", "true", null );
      }
      writer.writeText( String.format( "%04d", value ), null );
      writer.endElement( "option" );
    }
    writer.endElement( "select" );
    writer.writeText( " ", null );

    // write month selection
    writer.startElement( "select", this );
    writer.writeAttribute( "name", clientId + ":month", null );
    for ( int value = 1; value <= 12; value++ )
    {
      writer.startElement( "option", this );
      writer.writeAttribute( "value", value, null );
      if ( value == month )
      {
        writer.writeAttribute( "selected", "true", null );
      }
      writer.writeText( String.format( "%02d", value ), null );
      writer.endElement( "option" );
    }
    writer.endElement( "select" );
  }

  /**
   * Decodes the date from the request.
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   */
  public void decode( FacesContext context )
  {
    String clientId = getClientId( context );
    Map params = context.getExternalContext().getRequestParameterMap();
    int year = Integer.parseInt( (String) params.get( clientId + ":year" ) );
    int month = Integer.parseInt( (String) params.get( clientId + ":month" ) );
    Calendar calendar = new GregorianCalendar( year, month - 1, 1 );
    setSubmittedValue( calendar.getTime() );
  }
}