package org.books.view.component;

import java.io.IOException;
import java.util.Iterator;

import javax.faces.application.FacesMessage;
import javax.faces.component.UIMessage;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Beschreibung:<br/>
 * Diese Klasse rendert die Werte des message icon -Tags fuer die Ausgabe in der Java Server Page (tag library).
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version   1.0 - 15.05.2007
 * @see       UIMessage @link{javax.faces.component.UIMessage}
 */
public class MessageIcon extends UIMessage
{
  /**
   * The identifier od the component.
   */
  public static final String COMPONENT_TYPE = "MessageIcon";

  /**
   * title attribut for tooltip
   */
  private String title;

  /**
   * Default constructor
   * Set the renderer type
   */
  public MessageIcon()
  {
    setRendererType( null );
  }

  /**
   * Renders the message icon to the response.
   * @param context FacesContext
   * @throws IOException
   */
  public void encodeBegin( FacesContext context ) throws IOException
  {
    Iterator it = context.getMessages( findComponentId( getClientId( context ), getId(), getFor() ) );
    if ( it.hasNext() )
    {
      ResponseWriter writer = context.getResponseWriter();
      HttpServletRequest request = (HttpServletRequest) context.getExternalContext().getRequest();
      writer.startElement( "img", this );
      writer.writeAttribute( "id", getClientId( context ), null );
      String url = (String) getAttributes().get( "url" );
      if ( url != null )
      {
        String urlContext = request.getContextPath() + url;
        writer.writeAttribute( "src", urlContext, null );
      }
      String alt = (String) getAttributes().get( "alt" );
      if ( alt != null )
      {
        writer.writeAttribute( "alt", alt, null );
      }
      String width = (String) getAttributes().get( "width" );
      if ( width != null )
      {
        writer.writeAttribute( "width", width, null );
      }
      String height = (String) getAttributes().get( "height" );
      if ( height != null )
      {
        writer.writeAttribute( "height", height, null );
      }

      String border = (String) getAttributes().get( "border" );
      if ( border != null )
      {
        writer.writeAttribute( "border", border, null );
      }

      String styleClass = (String) getAttributes().get( "styleClass" );
      if ( styleClass != null )
      {
        writer.writeAttribute( "class", styleClass, null );
      }

      // set tooltip
      while ( it.hasNext() )
      {
        FacesMessage message = (FacesMessage) it.next();
        String errorMsg = "";
        if ( message.getSummary() != null || message.getSummary().length() > 0 )
        {
          errorMsg = errorMsg + message.getSummary();
        }
        title = errorMsg;
      }

      if ( title != null )
      {
        writer.writeAttribute( "title", title, null );
      }
      writer.endElement( "img" );
      writer.flush();
    }
  }

  /**
   * Diese Methode initialisiert den Wert fuer die Komponente.<br/>
   * This method initialize the value for the component.
   * @param clientContextId String  client context id
   * @param componentId String id error icon tag
   * @param _for String reference to component id
   * @return String form id
   */
  private String findComponentId( String clientContextId, String componentId, String _for )
  {
    String formId = clientContextId;
    formId = formId.replaceAll( componentId, "" ) + _for;
    return formId;
  }
}
