package org.books.view.component;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.faces.application.FacesMessage;
import javax.faces.component.StateHolder;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.validator.Validator;
import javax.faces.validator.ValidatorException;

import org.books.common.CommonConstants;
import org.books.view.MessageFactory;

/**
 * <p>
 * CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/>
 * Modul: Web-Tier (JSF)<br/>
 * Uebung: 10 (Custom Validator and Converter Tags)<br/>
 * Beschreibung:<br/>
 * Diese Klasse implementiert einen Validator fuer Reulaere Ausdruecke.
 * </p>
 * <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author    Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version   1.0 - 11.05.2007
 * @see       Validator @link{javax.faces.validator.Validator}
 * @see       StateHolder @link{javax.faces.component.StateHolder}
 */
public class RegexValidator implements Validator, StateHolder
{
  //TODO: Message uebergeben
  /** The identifier of the validator. */
  public static final String VALIDATOR_ID = "RegexValidator";

  /** The pattern of the regular expression. */
  private Pattern pattern;

  /** The transient value. */
  private boolean transientValue = false;

  //-----------------------------------------------------------------------------
  // A C T I O N   M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Validates a text against the regular expression.
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @param component UIComponent {@link javax.faces.component.UIComponent} the component
   * @param value Object
   * @throws ValidatorException
   */
  public void validate( FacesContext context, UIComponent component, Object value ) throws ValidatorException
  {
    Matcher matcher = pattern.matcher( (String) value );
    if ( !matcher.matches() )
    {
      throw new ValidatorException( MessageFactory.getMessage( FacesMessage.SEVERITY_ERROR, CommonConstants.ERR_INVALID_FORMAT_MESSAGE_ID, pattern ) );
    }
  }

  //-----------------------------------------------------------------------------
  // G E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Returns the transient value.
   * @return boolean
   */
  public boolean isTransient()
  {
    return transientValue;
  }

  /**
   * Saves the state of the validator.
   * @param context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @return Object
   */
  public Object saveState( FacesContext context )
  {
    return pattern;
  }

  //-----------------------------------------------------------------------------
  // S E T T E R - M E T H O D S
  //-----------------------------------------------------------------------------

  /**
   * Sets the transient value.
   * @param value boolean
   */
  public void setTransient( boolean value )
  {
    transientValue = value;
  }

  /**
   * Sets the pattern of the regular expression.
   * @param pattern String
   */
  public void setPattern( String pattern )
  {
    this.pattern = Pattern.compile( pattern );
  }

  /**
   * Restores the state of the validator.
   * @param context context FacesContext {@link javax.faces.context.FacesContext} the faces context
   * @param state Object
   */
  public void restoreState( FacesContext context, Object state )
  {
    pattern = (Pattern) state;
  }
}