package org.books.view.component;

import javax.el.ValueExpression;
import javax.faces.application.Application;
import javax.faces.context.FacesContext;
import javax.faces.validator.Validator;
import javax.faces.webapp.ValidatorELTag;
import javax.servlet.jsp.JspException;

/**
 * <p> CAS Enterprise Application Development mit Java EE (EADJ) - 2007<br/> Modul: Web-Tier (JSF)<br/> Uebung: 10 (Custom Validator and Converter Tags)<br/> Beschreibung:<br/> Diese Klasse implementiert einen Validator Tag fuer Reulaere Ausdruecke. </p> <p>Copyright (c) 2007 bouquet dot ch, 3032 Hinterkappelen. All rights reseved.</p>
 * @author     Marc Bouquet ( marc at bouquet dot ch, Switzerland )
 * @version    1.0 - 11.05.2007
 * @see ValidatorELTag  @link{javax.faces.webapp.ValidatorELTag}
 */
public class RegexValidatorTag extends ValidatorELTag
{
  /**
   * Default serial version uid
   */
  private static final long serialVersionUID = 1L;

  /**
   * The pattern of the regular expression.
   */
  private ValueExpression pattern;

  /**
   * Creates a validator instance.
   * @throws JspException
   */
  protected Validator createValidator() throws JspException
  {
    FacesContext context = FacesContext.getCurrentInstance();
    Application app = context.getApplication();
    RegexValidator validator = (RegexValidator) app.createValidator( RegexValidator.VALIDATOR_ID );
    if ( pattern.isLiteralText() )
    {
      validator.setPattern( pattern.getExpressionString() );
    }
    else
    {
      validator.setPattern( (String) pattern.getValue( context.getELContext() ) );
    }
    return validator;
  }

  /**
   * Sets the pattern of the regular expression.
   * @param pattern  ValueExpression
   */
  public void setPattern( ValueExpression pattern )
  {
    this.pattern = pattern;
  }

  /**
   * Releases the resources.
   */
  public void release()
  {
    super.release();
    pattern = null;
  }
}